from typing import Any, Dict, List, Optional, Set, Tuple, Union  # noqa
import json
import os


def dummy():
    return True


def help(
    *,
    module_name: str,
    source_dir: str,
    verbose: bool = False,
    ignores: Set[str],
    ignore_docs: bool = False,
):
    files = sorted(
        f for f in os.listdir(source_dir) if f.endswith(".py") and f not in ignores
    )
    from geoview import doc_url

    print(f"{module_name}:")
    for i, f in enumerate(files):
        print(f'\t{i:3d}:\tpython3 -m {module_name}.{f[:f.index(".")]} --help')
    if verbose:
        for f in files:
            cmd = f'python3 -m {module_name}.{f[:f.index(".")]} --help'
            print("\n\n\n", "*" * 80, sep="")
            print(f"$ {cmd}")
            os.system(cmd)

    if not ignore_docs:
        print("\n===== GEOVIEW =====\n\n  - ", end="")
        print(
            "\n  - ".join(
                [
                    f"document: {doc_url}",
                    "installation: python3 -m pip install geoview -U",
                ]
            )
        )
        print("\nversion: " + json.dumps(version(), indent=4))


def version() -> Dict[str, str]:
    try:
        from geoview import (
            __version__,
            package_name,
            git_branch,
            git_commit_hash,
            git_commit_date,
            git_commit_count,
            git_diff_name_only,
            doc_url,
        )

        ret = {
            "__version__": __version__,
            "package_name": package_name,
            "git_branch": git_branch,
            "git_commit_hash": git_commit_hash,
            "git_commit_date": git_commit_date,
            "git_commit_count": git_commit_count,
            "git_diff_name_only": git_diff_name_only,
            "doc_url": doc_url,
        }
    except ImportError as e:
        ret = {
            "error": f"failed to get repolint version info, error: {repr(e)}",
        }
    return ret



# DO NOT EDIT THIS FILE, IT IS GENERATED BY SETUP.PY
__version__ = "0.0.1"
package_name = "geoview"
git_branch = "tzx/0206"
git_commit_hash = "8895c28"
git_commit_date = "2023/02/06 23:43:10"
git_commit_count = 2
git_diff_name_only = ""
doc_url = "TODO"
repo_url = "https://github.com/cubao/geoview"



# DO NOT EDIT THIS FILE, IT IS GENERATED BY SETUP.PY
__version__ = "0.0.1"
package_name = "geoview"
git_branch = "main"
git_commit_hash = "e941031"
git_commit_date = "2023/02/06 23:51:23"
git_commit_count = 2
git_diff_name_only = "setup.py"
doc_url = "https://pypi.org/project/geoview"
repo_url = "https://github.com/cubao/geoview"



import glob
import subprocess

from setuptools import find_packages, setup


def sh(command):
    if isinstance(command, list):
        command = " ".join(command)
    return (
        subprocess.check_output(
            command,
            shell=True,
            stderr=subprocess.STDOUT,
        )
        .decode("utf-8")
        .rstrip()
    )


PACKAGE_NAME = "geoview"
VERSION = "0.0.1"

git_branch = sh("git rev-parse --abbrev-ref HEAD")
git_commit_hash = sh("git log -1 --format=%h")
git_commit_date = sh('git log -1 --date=format:"%Y/%m/%d %H:%M:%S" --format="%cd"')
git_commit_count = sh("git rev-list --count HEAD")
git_diff_name_only = sh("git diff --name-only")
if git_diff_name_only:
    git_diff_name_only = git_diff_name_only.replace("\n", ",")

doc_url = "https://pypi.org/project/geoview"
repo_url = "https://github.com/cubao/geoview"

# this is a hack, the easiest way I found to inject these metedata
with open(f"{PACKAGE_NAME}/__init__.py", "w") as f:
    f.write("# DO NOT EDIT THIS FILE, IT IS GENERATED BY SETUP.PY\n")
    f.write(f'__version__ = "{VERSION}"\n')
    f.write(f'package_name = "{PACKAGE_NAME}"\n')
    f.write(f'git_branch = "{git_branch}"\n')
    f.write(f'git_commit_hash = "{git_commit_hash}"\n')
    f.write(f'git_commit_date = "{git_commit_date}"\n')
    f.write(f"git_commit_count = {git_commit_count}\n")
    f.write(f'git_diff_name_only = "{git_diff_name_only}"\n')
    f.write(f'doc_url = "{doc_url}"\n')
    f.write(f'repo_url = "{repo_url}"\n')

with open("requirements.txt") as f:
    lines = f.readlines()
install_requires = [
    line.strip() for line in lines if line and not line.startswith("--")
]

data_export = [e[len("geoview/") :] for e in sorted(glob.glob("geoview/frontent/*"))]
setup(
    name=PACKAGE_NAME,
    version=VERSION,
    keywords=["geojson", "view"],
    description="geoview: view geojson data",
    url=doc_url,
    author="district10",
    author_email="dvorak4tzx@gmail.com",
    packages=find_packages(),
    platforms="any",
    zip_safe=False,
    include_package_data=True,
    package_data={
        f"{PACKAGE_NAME}": data_export,
    },
    install_requires=install_requires,
    python_requires=">=3.6",  # for those py35 or less users, please try f-string
)



from .utils import help
import os

if __name__ == "__main__":
    PWD = os.path.abspath(os.path.dirname(__file__))
    help(
        module_name="geoview",
        source_dir=PWD,
        ignores={"__init__.py", "__main__.py", "utils.py"},
        ignore_docs=True,
    )
    help(
        module_name="geoview.cli",
        source_dir=f"{PWD}/cli",
        ignores={"__init__.py", "__main__.py"},
        ignore_docs=False,
    )
